pub enum MessageType {
DefaultMarkdown(MessageDefaultMarkdown),
MessagePinned(MessagePin),
MemberAdd(MessageMember),
MemberRemove(MessageMember),
MemberJoin,
Call(MessageCall),
ThreadRename(MessageThreadRename),
ThreadPingback(MessageThreadPingback),
}Variants
DefaultMarkdown(MessageDefaultMarkdown)
a basic message, using markdown
MessagePinned(MessagePin)
a message was pinned
MemberAdd(MessageMember)
a thread member was added to the thread or group dm
MemberRemove(MessageMember)
a thread member was removed from the thread or group dm
MemberJoin
a room member joined the room
Call(MessageCall)
(TODO) call ended in a dm/gdm
ThreadRename(MessageThreadRename)
this thread was renamed
ThreadPingback(MessageThreadPingback)
(TODO) someone mentioned this thread
Implementations
Sourceimpl MessageType
impl MessageType
pub fn is_deletable(&self) -> bool
pub fn is_editable(&self) -> bool
pub fn is_movable(&self) -> bool