pub struct Channel {Show 29 fields
pub id: Id<MarkerChannel>,
pub room_id: Option<Id<MarkerRoom>>,
pub creator_id: Id<MarkerUser>,
pub owner_id: Option<Id<MarkerUser>>,
pub version_id: Id<MarkerChannelVer>,
pub name: String,
pub description: Option<String>,
pub ty: ChannelType,
pub member_count: u64,
pub online_count: u64,
pub tags: Vec<Id<MarkerTag>>,
pub deleted_at: Option<Time>,
pub archived_at: Option<Time>,
pub locked: bool,
pub parent_id: Option<Id<MarkerChannel>>,
pub position: Option<u16>,
pub permission_overwrites: Vec<PermissionOverwrite>,
pub nsfw: bool,
pub last_version_id: Option<Id<MarkerMessageVer>>,
pub message_count: Option<u64>,
pub root_message_count: Option<u64>,
pub bitrate: Option<u64>,
pub user_limit: Option<u64>,
pub is_unread: Option<bool>,
pub last_read_id: Option<Id<MarkerMessageVer>>,
pub mention_count: Option<u64>,
pub user_config: Option<UserConfigChannel>,
pub recipients: Vec<User>,
pub icon: Option<Id<MarkerMedia>>,
}Expand description
A channel
Fields
id: Id<MarkerChannel>room_id: Option<Id<MarkerRoom>>creator_id: Id<MarkerUser>owner_id: Option<Id<MarkerUser>>owner of the group dm
version_id: Id<MarkerChannelVer>only updates when the channel itself is updated, not the stuff in the channel
name: Stringdescription: Option<String>ty: ChannelTypetype specific data for this channel
member_count: u64number of people in this room
online_count: u64number of people who are online in this room
tags that are applied to this thread
deleted_at: Option<Time>archived_at: Option<Time>locked: boola locked channel can only be interacted with (sending messages,
(un)archiving, etc) by people with the ThreadLock permission
parent_id: Option<Id<MarkerChannel>>the channel this channel is in, if any
position: Option<u16>the position of this channel in the navbar
- lower numbers come first (0 is the first channel)
- channels with the same position are tiebroken by id
- channels without a position come last, ordered by newest first
permission_overwrites: Vec<PermissionOverwrite>permission overwrites for this channel
nsfw: boolnot safe for work
last_version_id: Option<Id<MarkerMessageVer>>message_count: Option<u64>root_message_count: Option<u64>bitrate: Option<u64>bitrate, for voice channels. defaults to 65535 (64Kibps).
user_limit: Option<u64>maximum number of users who can be in this voice channel
is_unread: Option<bool>last_read_id: Option<Id<MarkerMessageVer>>mention_count: Option<u64>user_config: Option<UserConfigChannel>recipients: Vec<User>for dm and gdm channels, this is who the dm is with
icon: Option<Id<MarkerMedia>>for gdm channels, a custom icon
Implementations