pub struct Message {Show 13 fields
pub message_type: MessageType,
pub id: Id<MarkerMessage>,
pub channel_id: Id<MarkerChannel>,
pub version_id: Id<MarkerMessageVer>,
pub nonce: Option<String>,
pub author_id: Id<MarkerUser>,
pub mentions: Mentions,
pub pinned: Option<Pinned>,
pub reactions: ReactionCounts,
pub created_at: Option<Time>,
pub deleted_at: Option<Time>,
pub removed_at: Option<Time>,
pub edited_at: Option<Time>,
}Fields
message_type: MessageTypeid: Id<MarkerMessage>channel_id: Id<MarkerChannel>version_id: Id<MarkerMessageVer>nonce: Option<String>unique string sent by the client via idempotency-key to identify this message
the id of who sent this message
mentions: Mentionspinned: Option<Pinned>exists if this message is pinned
reactions: ReactionCountscreated_at: Option<Time>deleted_at: Option<Time>deleted messages can still be viewed by moderators for a period of time, but otherwise cannot be recovered
removed_at: Option<Time>removed messages are hidden for non moderators. they are recoverable by moderators
edited_at: Option<Time>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Message
impl<'de> Deserialize<'de> for Message
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Message, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Message, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl Serialize for Message
impl Serialize for Message
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Sourceimpl<'v_a> ValidateArgs<'v_a> for Message
impl<'v_a> ValidateArgs<'v_a> for Message
type Args = ()
fn validate_with_args( &self, args: <Message as ValidateArgs<'v_a>>::Args, ) -> Result<(), ValidationErrors>