pub struct Puppet {
pub owner_id: Id<MarkerUser>,
pub external_platform: ExternalPlatform,
pub external_id: String,
pub external_url: Option<Url>,
pub alias_id: Option<Id<MarkerUser>>,
}Expand description
represents a user on another platform
Fields
owner_id: Id<MarkerUser>the user who created this puppet
external_platform: ExternalPlatformwhat platform this puppet is connected to
external_id: Stringan opaque identifier from the other platform
external_url: Option<Url>a url on the other platform that this account can be reached at
alias_id: Option<Id<MarkerUser>>makes two users be considered the same user, for importing stuff from other platforms can you alias to another puppet?